@@ -74,7 +74,9 @@ def get_clip(slug):
     query = """
     {{
         clip(slug: "{}") {{
+            id
             title
+            createdAt
             durationSeconds
             game {{
                 name
@@ -82,6 +84,9 @@ def get_clip(slug):
             broadcaster {{
                 login
                 displayName
+                channel {{
+                  name
+                }}
             }}
             videoQualities {{
                 frameRate
@@ -154,6 +159,10 @@ def get_channel_clips(channel_id, period, limit, after=None):
     })
 
     response = gql_query(query)
+    user = response["data"]["user"]
+    if not user:
+        raise ConsoleError("Channel {} not found".format(channel_id))
+
     return response["data"]["user"]["clips"]
 
 
